==> 1.0.9-dev.tar.gz: example/lib/ui/activity_data_delegate.dart <==
import 'package:example/localization/labels.dart';
import 'package:flutter/material.dart';
import 'package:flutterx_application/flutterx_application.dart';

class DataDelegateActivity extends StatefulWidget {
  static final ActivityRoute<String?> route = ActivityRoute.builder(DataDelegateActivity,
      systemUiStyle: (context) =>
          Application.defaultSystemUiStyle(context).copyWith(statusBarIconBrightness: Brightness.dark),
      builder: (context, args) => DataDelegateActivity._(message: args['message']));

  static Future<String?> openReplace(BuildContext context, {required String message, Object? result}) =>
      route.openReplace(context, args: {'message': message}, result: result);

  static Future<String?> openForward(BuildContext context, {required String message}) =>
      route.openForward<String?>(context, args: {'message': message});

  final String message;

  const DataDelegateActivity._({Key? key, required this.message}) : super(key: key);

  @override
  State<DataDelegateActivity> createState() => _DataDelegateActivityState();
}

class _DataDelegateActivityState extends State<DataDelegateActivity> {
  @override
  Widget build(BuildContext context) => Scaffold(
      appBar: AppBar(title: Text(labels.appName)),
      body: Center(
        child: Column(mainAxisAlignment: MainAxisAlignment.center, children: [
          Text(widget.message),
          ElevatedButton(onPressed: () => Navigator.pop(context, widget.message), child: const Text('RETURN')),
        ]),
      ));
}

==> 1.1.13-dev.tar.gz: example/lib/ui/activity_data_delegate.dart <==
import 'package:example/localization/labels.dart';
import 'package:flutter/material.dart';
import 'package:flutterx_application/flutterx_application.dart';

class DataDelegateActivity extends StatefulWidget {
  static final ActivityRoute<String?> route = ActivityRoute(
      title: (_) => 'Delegate',
      location: '/delegate_activity',
      systemUiStyle: (context) => defaultSystemUiStyle(context).copyWith(statusBarIconBrightness: Brightness.dark),
      builder: (context, args) => DataDelegateActivity._(message: args['message']));

  static Future<String?> openReplace(BuildContext context, {required String message, Object? result}) =>
      route.openReplace(context, args: {'message': message});

  static Future<String?> openForward(BuildContext context, {required String message}) =>
      route.open(context, args: {'message': message});

  final String message;

  const DataDelegateActivity._({Key? key, required this.message}) : super(key: key);

  @override
  State<DataDelegateActivity> createState() => _DataDelegateActivityState();
}

class _DataDelegateActivityState extends State<DataDelegateActivity> {
  @override
  Widget build(BuildContext context) => Scaffold(
      appBar: AppBar(title: Text(labels.appName)),
      body: Center(
        child: Column(mainAxisAlignment: MainAxisAlignment.center, children: [
          Text(widget.message),
          ElevatedButton(onPressed: () => Navigator.pop(context, widget.message), child: const Text('RETURN')),
        ]),
      ));
}
